@@ -1,20 +1,20 @@
 ## create temporary dataset to run the testing
 data1 <- iris[1:2, ]
-data2 <- data1 %>% rtf_body()
+data2 <- data1 |> rtf_body()
 
 test_that("Test if type input is not table or figure", {
-  expect_error(data2 %>% rtf_encode(type = "plot"))
+  expect_error(data2 |> rtf_encode(type = "plot"))
 })
 
 test_that("Test if title/footnote/source input is not first, all, last", {
-  expect_error(data2 %>% rtf_encode(page_title = "middle"))
-  expect_error(data2 %>% rtf_encode(page_footnote = "firstlast"))
-  expect_error(data2 %>% rtf_encode(page_source = "ALL"))
+  expect_error(data2 |> rtf_encode(page_title = "middle"))
+  expect_error(data2 |> rtf_encode(page_footnote = "firstlast"))
+  expect_error(data2 |> rtf_encode(page_source = "ALL"))
 })
 
 test_that("Test if content is converted to RTF correctly when tbl class is list", {
-  x <- data.frame(1) %>% rtf_body()
-  y <- data.frame(1) %>% rtf_body()
+  x <- data.frame(1) |> rtf_body()
+  y <- data.frame(1) |> rtf_body()
   z <- list(x, y)
   expect_snapshot_output(rtf_encode(z, doc_type = "table"))
 })
@@ -24,11 +24,11 @@ test_that("Test if content is converted to RTF correctly when tbl class is data.
 })
 
 
-tbl <- rtf_read_figure("fig/fig1.png") %>% rtf_figure()
-tbl2 <- tbl %>%
-  rtf_title("This is the title") %>%
+tbl <- rtf_read_figure("fig/fig1.png") |> rtf_figure()
+tbl2 <- tbl |>
+  rtf_title("This is the title") |>
   rtf_footnote("This is a footnote")
-tbl3 <- tbl2 %>% rtf_encode(doc_type = "figure")
+tbl3 <- tbl2 |> rtf_encode(doc_type = "figure")
 
 
 test_that("Test if content is converted to RTF correctly when type is figure", {
